@@ -60,7 +60,6 @@ struct connman_device {
 	char *interface;
 	char *ident;
 	char *path;
-	char *devname;
 	int index;
 	guint pending_timeout;
 
@@ -186,6 +185,12 @@ int __connman_device_enable(struct connman_device *device)
 	if (device->powered_pending == PENDING_NONE && device->powered)
 		return -EALREADY;
 
+	if (device->index > 0) {
+		err = connman_inet_ifup(device->index);
+		if (err < 0 && err != -EALREADY)
+			return err;
+	}
+
 	device->powered_pending = PENDING_ENABLE;
 
 	err = device->driver->enable(device);
@@ -386,7 +391,6 @@ static void device_destruct(struct connman_device *device)
 	g_free(device->address);
 	g_free(device->interface);
 	g_free(device->path);
-	g_free(device->devname);
 
 	g_free(device->last_network);
 
@@ -522,9 +526,6 @@ int connman_device_get_index(struct connman_device *device)
 void connman_device_set_interface(struct connman_device *device,
 						const char *interface)
 {
-	g_free(device->devname);
-	device->devname = g_strdup(interface);
-
 	g_free(device->interface);
 	device->interface = g_strdup(interface);
 
@@ -567,7 +568,7 @@ int connman_device_set_powered(struct connman_device *device,
 {
 	enum connman_service_type type;
 
-	DBG("driver %p powered %d", device, powered);
+	DBG("device %p powered %d", device, powered);
 
 	if (device->powered == powered)
 		return -EALREADY;
