@@ -208,6 +208,8 @@ static void send_packet(int fd, const char *server, uint32_t timeout)
 
 static gboolean next_poll(gpointer user_data)
 {
+	poll_id = 0;
+
 	if (!timeserver || transmit_fd == 0)
 		return FALSE;
 
@@ -218,8 +220,10 @@ static gboolean next_poll(gpointer user_data)
 
 static void reset_timeout(void)
 {
-	if (timeout_id > 0)
+	if (timeout_id > 0) {
 		g_source_remove(timeout_id);
+		timeout_id = 0;
+	}
 
 	retries = 0;
 }
@@ -328,14 +332,14 @@ static void decode_msg(void *base, size_t len, struct timeval *tv,
 		adj.tv_sec = (long) offset;
 		adj.tv_usec = (offset - adj.tv_sec) * 1000000;
 
-		DBG("adjusting time");
+		DBG("adjusting time %ld seconds, %ld msecs", adj.tv_sec, adj.tv_usec);
 
 		if (adjtime(&adj, &adj) < 0) {
 			connman_error("Failed to adjust time");
 			return;
 		}
 
-		DBG("%lu seconds, %lu msecs", adj.tv_sec, adj.tv_usec);
+		DBG("remaining adjustment %ld seconds, %ld msecs", adj.tv_sec, adj.tv_usec);
 	} else {
 		struct timeval cur;
 		double dtime;
@@ -345,14 +349,13 @@ static void decode_msg(void *base, size_t len, struct timeval *tv,
 		cur.tv_sec = (long) dtime;
 		cur.tv_usec = (dtime - cur.tv_sec) * 1000000;
 
-		DBG("setting time");
+		DBG("setting time: %ld seconds, %ld msecs", cur.tv_sec, cur.tv_usec);
 
 		if (settimeofday(&cur, NULL) < 0) {
 			connman_error("Failed to set time");
 			return;
 		}
 
-		DBG("%lu seconds, %lu msecs", cur.tv_sec, cur.tv_usec);
 	}
 }
 
@@ -501,8 +504,10 @@ void __connman_ntp_stop()
 {
 	DBG("");
 
-	if (poll_id > 0)
+	if (poll_id > 0) {
 		g_source_remove(poll_id);
+		poll_id = 0;
+	}
 
 	reset_timeout();
 
